#!/bin/bash

# This script creates bash script in the current directory
# called 'locoo3d'.  It will call the locoo3d_1.11.1.jar
# file as a runnable jar.
#
# In order for database connectivity to work, users must find the location of
# the Oracle file ojdbc<x>.jar on their system and specify that location here
# (no spaces around the '=' sign!).  If this variable is ommitted or blank
# database IO will not be possible but flat file IO will be possible.

OJDBC=

echo "Creating executable script file locoo3d that launches LocOO3D"
echo "#!/bin/bash" > locoo3d
echo "#" >> locoo3d
echo "# The substring '-Xmx????m' in the following execution" >> locoo3d
echo "# command specifies the amount of memory to make available" >> locoo3d
echo "# to the application, in megabytes." >> locoo3d
echo "#" >> locoo3d
echo "java -Xmx1400m -classpath $(pwd)/locoo3d_1.11.1.jar:${OJDBC} gov.sandia.gmp.locoo3d.LocOO  \$*" >> locoo3d
chmod 777 locoo3d

echo "Creating executable script file supportmap that launches SupportMap"
echo "#!/bin/bash" > supportmap
echo "#" >> supportmap
echo "# The substring '-Xmx????m' in the following execution" >> supportmap
echo "# command specifies the amount of memory to make available" >> supportmap
echo "# to the application, in megabytes." >> supportmap
echo "#" >> supportmap
echo "java -Xmx1400m -classpath $(pwd)/supportmap_1.2.3.jar:${OJDBC} gov.sandia.libcorr3d.supportmap.SupportMap  \$*" >> supportmap
chmod 777 supportmap

echo "Creating executable script file supportmap that launches GeoTessExplorer"
echo "#!/bin/bash" > geotess
echo "#" >> geotess
echo "# The substring '-Xmx????m' in the following execution" >> geotess
echo "# command specifies the amount of memory to make available" >> geotess
echo "# to the application, in megabytes." >> geotess
echo "#" >> geotess
echo "java -Xmx1400m -classpath $(pwd)/geotess_2.5.1.jar gov.sandia.geotess.GeoTessExplorer  \$*" >> geotess
chmod 777 geotess

echo "Creating executable script file supportmap that launches libcorr3d_1.2.3.jar"
echo "#!/bin/bash" > libcorr3d
echo "#" >> libcorr3d
echo "# The substring '-Xmx????m' in the following execution" >> libcorr3d
echo "# command specifies the amount of memory to make available" >> libcorr3d
echo "# to the application, in megabytes." >> libcorr3d
echo "#" >> libcorr3d
echo "java -Xmx1400m -classpath $(pwd)/libcorr3d_1.2.3.jar gov.sandia.gmp.libcorr3djava.LibCorr3DExplorer  \$*" >> libcorr3d
chmod 777 libcorr3d

# The script also prints to screen recommended addition to 
# the user's .cshrc or .bash_profile that will make the new
# executable available via the PATH.  No changes to the user's
# environment are actually made.

if [ `uname -s` = Darwin ]; then
	echo "Add this line to your .bash_profile"
	echo "export PATH=$(pwd):\$PATH"
else
	echo "Add this line to your .cshrc file"
	echo "set path=( $(pwd) \$path )"
fi
